import { renderless, api } from '@opentinyvue/vue-renderless/date-panel/vue';
import { defineComponent, $prefix, directive, setup, $props } from '@opentinyvue/vue-common';
import { language } from '@opentinyvue/vue-locale';
import { Clickoutside } from '@opentinyvue/vue-directive';
import Time from '@opentinyvue/vue-time';
import DateTable from '@opentinyvue/vue-date-table';
import YearTable from '@opentinyvue/vue-year-table';
import MonthTable from '@opentinyvue/vue-month-table';
import Input from '@opentinyvue/vue-input';
import Button from '@opentinyvue/vue-button';
import { iconDoubleRight, iconDoubleLeft, iconChevronLeft, iconChevronRight, iconChevronDown, iconChevronUp } from '@opentinyvue/vue-icon';
import Popup from '@opentinyvue/vue-popup';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  name: $prefix + "DatePanel",
  directives: directive({
    Clickoutside
  }),
  components: {
    TimePicker: Time,
    YearTable,
    MonthTable,
    DateTable,
    TinyInput: Input,
    TinyButton: Button,
    TinyPopup: Popup,
    IconDoubleRight: iconDoubleRight(),
    IconDoubleLeft: iconDoubleLeft(),
    IconChevronLeft: iconChevronLeft(),
    IconChevronRight: iconChevronRight(),
    IconChevronDown: iconChevronDown(),
    IconChevronUp: iconChevronUp()
  },
  props: _extends({}, $props, {
    emitter: Object,
    step: {
      type: Object,
      default: function _default() {
        return {
          hour: 1,
          minute: 1,
          second: 1
        };
      }
    },
    showWeekNumber: {
      type: Boolean,
      default: false
    },
    formatWeeks: Function,
    type: {
      type: String,
      default: ""
    },
    firstDayOfWeek: {
      type: Number,
      default: 7
    },
    timeEditable: {
      type: Boolean,
      default: true
    },
    nowClick: {
      type: Function
    },
    modelValue: {
      type: [Date, String, Number],
      default: ""
    },
    format: {
      type: String,
      default: ""
    },
    readonly: {
      type: Boolean,
      default: false
    },
    shortcuts: {
      type: Array,
      default: function _default2() {
        return [];
      }
    },
    disabledDate: {
      type: Function,
      default: function _default3() {
        return null;
      }
    },
    popperClass: {
      type: String,
      default: ""
    }
  }),
  emits: ["pick", "select-change", "update:modelValue", "dodestroy"],
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      extendOptions: {
        language
      }
    });
  }
});
var render = function render2() {
  var _vm$state$shortcuts, _vm$state$shortcuts2;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-zoom-in-top"
    },
    on: {
      "after-enter": _vm.handleEnter,
      "after-leave": _vm.handleLeave
    }
  }, [_c("div", {
    staticClass: "tiny-picker-panel tiny-date-picker tiny-popper",
    class: [{
      "has-sidebar": _vm.slots.sidebar || ((_vm$state$shortcuts = _vm.state.shortcuts) === null || _vm$state$shortcuts === void 0 ? void 0 : _vm$state$shortcuts.length),
      "has-time": _vm.state.showTime
    }, _vm.state.popperClass]
  }, [_c("div", {
    staticClass: "tiny-picker-panel__body-wrapper"
  }, [_vm._t("sidebar"), (_vm$state$shortcuts2 = _vm.state.shortcuts) !== null && _vm$state$shortcuts2 !== void 0 && _vm$state$shortcuts2.length ? _c("div", {
    staticClass: "tiny-picker-panel__sidebar"
  }, _vm._l(_vm.state.shortcuts, function(shortcut, key) {
    return _c("button", {
      key,
      staticClass: "tiny-picker-panel__shortcut",
      attrs: {
        "type": "button",
        "title": shortcut.text
      },
      on: {
        "click": function click($event) {
          return _vm.handleShortcutClick(shortcut);
        }
      }
    }, [_vm._v(" " + _vm._s(shortcut.text) + " ")]);
  }), 0) : _vm._e(), _c("div", {
    staticClass: "tiny-picker-panel__body"
  }, [_vm.state.showTime ? _c("div", {
    staticClass: "tiny-date-picker__time-header"
  }, [_c("span", {
    staticClass: "tiny-date-picker__editor-wrap"
  }, [_c("tiny-input", {
    attrs: {
      "placeholder": _vm.t("ui.datepicker.selectDate"),
      "model-value": _vm.state.visibleDate,
      "size": "small"
    },
    on: {
      "update:modelValue": function updateModelValue(val) {
        return _vm.state.userInputDate = val;
      },
      "change": _vm.handleVisibleDateChange
    }
  })], 1), _c("span", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleTimePickClose,
      expression: "handleTimePickClose"
    }],
    staticClass: "tiny-date-picker__editor-wrap"
  }, [_c("tiny-input", {
    ref: "input",
    attrs: {
      "placeholder": _vm.t("ui.datepicker.selectTime"),
      "model-value": _vm.state.visibleTime,
      "size": "small",
      "readonly": !_vm.timeEditable
    },
    on: {
      "focus": function focus($event) {
        _vm.state.timePickerVisible = true;
      },
      "update:modelValue": function updateModelValue(val) {
        return _vm.state.userInputTime = val;
      },
      "change": _vm.handleVisibleTimeChange
    }
  }), _c("time-picker", {
    ref: "timepicker",
    attrs: {
      "step": _vm.step,
      "time-arrow-control": _vm.state.arrowControl,
      "show": _vm.state.timePickerVisible,
      "value": _vm.state.date
    },
    on: {
      "pick": _vm.handleTimePick
    }
  })], 1)]) : _vm._e(), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.currentView !== "time",
      expression: "state.currentView !== 'time'"
    }],
    staticClass: "tiny-date-picker__header",
    class: {
      "tiny-date-picker__header--bordered": ["month", "year", "years", "yearrange"].includes(_vm.state.currentView)
    }
  }, [_c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__prev-btn tiny-icon-d-arrow-left",
    attrs: {
      "type": "button",
      "aria-label": _vm.t("ui.datepicker.prevYear")
    },
    on: {
      "click": _vm.cusPrevYear
    }
  }, [_c("icon-double-left")], 1), _c("button", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.currentView === "date",
      expression: "state.currentView === 'date'"
    }],
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__prev-btn tiny-icon-arrow-left",
    attrs: {
      "type": "button",
      "aria-label": _vm.t("ui.datepicker.prevMonth")
    },
    on: {
      "click": _vm.cusPrevMonth
    }
  }, [_c("icon-chevron-left")], 1), _c("span", {
    staticClass: "tiny-date-picker__header-label",
    attrs: {
      "role": "button"
    },
    on: {
      "click": function click($event) {
        return _vm.showHeaderPicker("Year");
      }
    }
  }, [_vm._v(" " + _vm._s(_vm.state.yearLabel) + " ")]), _c("span", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.currentView === "date",
      expression: "state.currentView === 'date'"
    }],
    staticClass: "tiny-date-picker__header-label",
    class: {
      active: _vm.state.currentView === "month"
    },
    attrs: {
      "role": "button"
    },
    on: {
      "click": function click($event) {
        return _vm.showHeaderPicker("Month");
      }
    }
  }, [_vm._v(_vm._s(_vm.t("ui.datepicker.month" + (_vm.state.month + 1))))]), _c("button", {
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__next-btn tiny-icon-d-arrow-right",
    attrs: {
      "type": "button",
      "aria-label": _vm.t("ui.datepicker.nextYear")
    },
    on: {
      "click": _vm.cusNextYear
    }
  }, [_c("icon-double-right")], 1), _c("button", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.currentView === "date",
      expression: "state.currentView === 'date'"
    }],
    staticClass: "tiny-picker-panel__icon-btn tiny-date-picker__next-btn tiny-icon-arrow-right",
    attrs: {
      "type": "button",
      "aria-label": _vm.t("ui.datepicker.nextMonth")
    },
    on: {
      "click": _vm.cusNextMonth
    }
  }, [_c("icon-chevron-right")], 1)]), _c("div", {
    staticClass: "tiny-picker-panel__content"
  }, [_c("div", {
    staticClass: "tiny-picker-panel__table"
  }, [_vm.state.currentView === "date" ? _c("date-table", {
    ref: "dateTable",
    attrs: {
      "selection-mode": _vm.state.selectionMode,
      "first-day-of-week": _vm.state.firstDayOfWeek,
      "value": _vm.state.value,
      "default-value": _vm.state.defaultValue ? new Date(_vm.state.defaultValue) : null,
      "date": _vm.state.date,
      "cell-class-name": _vm.state.cellClassName,
      "disabled-date": _vm.state.disabledDate,
      "show-week-number": _vm.showWeekNumber,
      "format-weeks": _vm.formatWeeks,
      "readonly": _vm.readonly
    },
    on: {
      "pick": _vm.handleDatePick
    }
  }) : _vm._e(), ["year", "years", "yearrange"].includes(_vm.state.currentView) ? _c("year-table", {
    ref: "yearTable",
    attrs: {
      "value": _vm.state.value,
      "default-value": _vm.state.defaultValue ? new Date(_vm.state.defaultValue) : null,
      "date": _vm.state.date,
      "disabled-date": _vm.state.disabledDate,
      "selection-mode": _vm.state.selectionMode,
      "start-year": _vm.state.startYear,
      "readonly": _vm.readonly
    },
    on: {
      "pick": _vm.handleYearPick
    }
  }) : _vm._e(), _vm.state.currentView === "month" ? _c("month-table", {
    ref: "monthTable",
    attrs: {
      "value": _vm.state.value,
      "default-value": _vm.state.defaultValue ? new Date(_vm.state.defaultValue) : null,
      "date": _vm.state.date,
      "disabled-date": _vm.state.disabledDate
    },
    on: {
      "pick": _vm.handleMonthPick
    }
  }) : _vm._e()], 1)])])], 2), _vm.state.isShowTz || _vm.state.timezone.isServiceTimezone ? _c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleTzPickClose,
      expression: "handleTzPickClose"
    }],
    staticClass: "tiny-picker-panel__timezone"
  }, [_c("tiny-input", {
    attrs: {
      "disabled": _vm.state.timezone.isServiceTimezone,
      "placeholder": _vm.t("ui.datepicker.timezone")
    },
    on: {
      "update:modelValue": _vm.searchTz
    },
    scopedSlots: _vm._u([{
      key: "suffix",
      fn: function fn() {
        return [_c(_vm.state.showpopup ? "IconChevronDown" : "IconChevronUp", {
          tag: "component",
          attrs: {
            "fill": "#ccc"
          },
          on: {
            "click": _vm.toggleTz
          }
        })];
      },
      proxy: true
    }], null, false, 3034754380),
    model: {
      value: _vm.state.tz,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "tz", $$v);
      },
      expression: "state.tz"
    }
  }), _c("div", {
    staticClass: "tiny-picker-panel__tzlist"
  }, [_c("tiny-popup", {
    attrs: {
      "overlay": false,
      "position": "up",
      "duration": 0.2,
      "closeable": false
    },
    model: {
      value: _vm.state.showpopup,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "showpopup", $$v);
      },
      expression: "state.showpopup"
    }
  }, [_c("div", {
    staticClass: "tzlist"
  }, [_c("ul", _vm._l(_vm.state.renderTzdata, function(tz, index) {
    return _c("li", {
      directives: [{
        name: "show",
        rawName: "v-show",
        value: !tz.visible,
        expression: "!tz.visible"
      }],
      key: index,
      staticClass: "tiny-picker-panel__tzlist-li",
      attrs: {
        "title": tz.name
      },
      on: {
        "click": function click($event) {
          return _vm.selectTz(tz);
        }
      }
    }, [_vm._v(" " + _vm._s(tz.name) + " ")]);
  }), 0)])])], 1)], 1) : _vm._e(), _vm.state.isShowFooter ? _c("div", {
    staticClass: "tiny-picker-panel__footer",
    style: {
      justifyContent: !["dates", "years"].includes(_vm.state.selectionMode) ? "space-between" : "right"
    }
  }, [_vm._t("default", function() {
    return [_c("tiny-button", {
      directives: [{
        name: "show",
        rawName: "v-show",
        value: !["dates", "years"].includes(_vm.state.selectionMode),
        expression: "!['dates', 'years'].includes(state.selectionMode)"
      }],
      staticClass: "tiny-picker-panel__link-btn",
      attrs: {
        "size": _vm.state.buttonSize,
        "type": "text"
      },
      on: {
        "click": _vm.changeToNow
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.now")) + " ")])];
  }), _c("tiny-button", {
    staticClass: "tiny-picker-panel__link-btn",
    attrs: {
      "type": _vm.state.buttonType,
      "size": _vm.state.buttonSize
    },
    on: {
      "click": _vm.confirm
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.datepicker.confirm")) + " ")])], 2) : _vm._e()])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
